@media screen {
/*Fairy*/
    $bg: #ECAAC5;
    $text: black;
    $lac: #A685E7;
    $box: #DFE7C0;
    #fairy {
    /* Default (small) screens */
        * {
            box-sizing: content-box;
        }
        body {
            background: $bg url("sparkles.png") 0% 5% repeat-x fixed;
            color: $text;
            text-align: center;
            font-size: 1.5em;
            font-family: sans-serif;
            margin: 0em;
        }

        main, figure {
            margin: 0em;
            padding-left: 0em;
            padding-right: 0em;
        }

        figure#comic, main > div, main > section {
            background: $box;
            border-top: solid thick $lac;
            border-bottom: solid thick $lac;
        }
        
        nav li, .cominavbox {
            background: $box;
            border: solid thick $lac;
        }

        h1 {
            margin: 0em;
        }

        h2 {
            margin-top: 0em
        }
        figure {
            text-align: center;
            border: none;
        }
        .cominavbox, .cominavbox li {
            display: inline-block;
            padding: 0em;
        }

        p + p, li + li, div+div, section+section, footer {
            margin-top: 0.5em
        }
        
        main > div, main > section {
            padding: 0.5em;
        }

        /*TODO: Fix the skip link hiding method*/
        #skippy {
            text-align: left;
        }
        #skippy a, #skippy a:hover, #skippy a:visited {
            position:absolute;
            left:-10000px;
            top:auto;
            width:1px;
            height:1px;
            overflow:hidden;
        }

        #skippy a:active, #skippy a:focus {
          position: static;
          height: auto;
          width: auto;
          font-size: 1em;
          margin-top: 0em;
          color: #0000ff;
        }
        
        nav {
            font-size: 1.2em;
        }

        nav li {
            display: inline-block;
        }

        #commentary, #transcript {
            text-align: left;
        }

        .statline {
            font-weight: bold;
        }

        a:link {
            color: #3434A2;
            text-decoration: underline
        }

        a:visited {
            color: #582574;
        }

        a:hover {
            text-decoration: underline
        }

        a:hover, a:focus, a:active {
            color: #8F0037;
        }

        footer {
            padding: 0.5em;
            text-align: left;
            background: $box;
            border-top: solid thick $lac;
            p {
                margin: 0em;
            }
        }

        .archive {
            display: inline-block;
            vertical-align: top;
            text-align: left;
        }

        img, embed, object, video {
            max-width: 100%;
        }

        .action {
            font-weight: bold;
        }
        
        .char {
            text-align: left;
            dt:after {
                content: ":"
            }
            dd:after {
                content: "\A"; white-space: pre;
            }
            dd {
                margin-left: 0em;
            }
            dt, dd {
                display: inline;
                white-space: pre;
            }
        }

        .charname {
            font-weight: bold;
        }
        
        .char img {
          margin: 0em;
          padding: 0em;
        }
        
        .chartraits {
          margin: 0em;
          padding: 0em;
        }
        
        .chardesc {
          border: none;
          padding: 0em;
          margin: 0em;
          line-height: 2em;
        }
          
        .intro {
            border: none;
            & + .intro {
                border-top: solid medium $lac;
                padding-top: 1em;
                margin-top: 0em;
            }
        }

    /*Medium screens*/

        @media screen and (min-width: 1024px) {
            main {
                margin: 1em;
            }
            figure {
                margin-left: 1em;
                margin-top: 0em;
                margin-bottom: 0em;
            }

            figure#comic, main > div, main > section {
                background: $box url("mornglor.png") top right no-repeat;
                border: solid thick $lac;
            }

            main > div, main > section {
                padding: 1em;
                width: 80%;
            }

            div + div {
                margin-bottom: 0em;
                margin-top: 1em;
            }

            .cominavbox, .cominavbox li {
                margin-left: 1em;
                margin-right: 1em;
                margin-top: 0.5em;
                margin-bottom: 0em;
            }
            
            .cominavbox li {
                padding: 1em;
            }

            figure + .cominavbox {
                margin-bottom: 1em;
            }
              
            figure {
                padding: 0em 2em 2em 2em;
                &#comic {
                    padding-top: 2em;
                    margin-top: 1em;
                    margin-left: 2em;
                    margin-right: 2em;
                }
            }
              
              figcaption {
                  padding-left: 2em;
                  padding-right: 2em;
              }

            h1 {
                font-size: 1.5em;
            }

            h2 {
                font-size: 1.2em;
            }
            
            h3 {
                font-size: 1em;
            }

            nav li {
                padding-top: 1em;
                padding-left: 1em;
                padding-right: 1em;
                padding-bottom: 0.8em;
                margin: 0em;
            }

            .statline {
                font-size: 0.8em;
                text-align: right;
            }

            .archive {
                padding: 1em 2em;
                margin: 1em;
            }
            
            .main {
                margin: 1em;
                text-align: left;
            }
            .char {
                text-align: left;
                img {
                    border: solid medium $lac;
                }
                img, .chartraits {
                    display: inline-block;
                    vertical-align: top;
                }
            }
            .chartraits {
                margin-left: 1em;
            }
            .chartraits * {
                line-height: 1.5em
            }
        }
    }
}
