@media screen {
  /*Sysadmin*/
  #sysadmin {
    /* Default (small) screens */
    /*TODO: Fix the skip link hiding method*/
    /*Medium screens*/ }
    #sysadmin * {
      box-sizing: content-box; }
    #sysadmin body {
      background: #000;
      color: #87df32;
      text-align: left;
      font-size: 2.2em;
      font-family: monospace; }
    #sysadmin main, #sysadmin figure {
      margin-left: 0em;
      padding-left: 0em; }
    #sysadmin header {
      text-align: center; }
    #sysadmin nav li {
      margin: 1.5em; }
    #sysadmin h1, #sysadmin h2, #sysadmin h3, #sysadmin h4, #sysadmin h5, #sysadmin h6 {
      font-size: 1em; }
    #sysadmin h1 {
      margin: 0em;
      text-align: left; }
    #sysadmin h2, #sysadmin h3 {
      padding-bottom: 1em;
      border-bottom: dashed medium #87df32; }
    #sysadmin figure {
      border: none;
      margin: 0em; }
    #sysadmin figure#comic img {
      padding: 0em;
      margin: 0em; }
    #sysadmin .cominavbox, #sysadmin .cominavbox li {
      display: inline-block;
      padding: 0em; }
    #sysadmin .cominavbox li {
      margin: 0em 1em; }
    #sysadmin * + * {
      margin-top: 0.5em; }
    #sysadmin #skippy {
      text-align: left; }
    #sysadmin #skippy a, #sysadmin #skippy a:hover, #sysadmin #skippy a:visited {
      position: absolute;
      left: -10000px;
      top: auto;
      width: 1px;
      height: 1px;
      overflow: hidden; }
    #sysadmin #skippy a:active, #sysadmin #skippy a:focus {
      position: static;
      height: auto;
      width: auto;
      font-size: 1em;
      margin-top: 0em;
      color: #ffffff; }
    #sysadmin nav li {
      display: inline-block; }
    #sysadmin #commentary, #sysadmin #transcript {
      text-align: left; }
    #sysadmin .statline {
      margin: 0em;
      padding: 0.5em 0.5em 0em 0.5em;
      font-weight: bold;
      text-align: right;
      border-top: dashed medium #87df32; }
    #sysadmin a:link {
      color: #429eff;
      text-decoration: underline; }
    #sysadmin a:visited {
      color: #ac39ff; }
    #sysadmin a:hover, #sysadmin a:focus, #sysadmin a:active {
      color: #ffffff; }
    #sysadmin footer p {
      margin-left: 0em;
      text-align: left; }
    #sysadmin .archive {
      text-align: left; }
    #sysadmin main > div, #sysadmin main > section {
      padding: 1em;
      border: dashed medium #87df32; }
    #sysadmin #extras * + h2, #sysadmin #extras h3 {
      padding-bottom: 0em;
      border: none;
      padding-top: 1em;
      border-top: dashed medium #87df32; }
    #sysadmin #extras h2:first-of-type {
      border: none;
      padding: 0em; }
    #sysadmin img, #sysadmin embed, #sysadmin object, #sysadmin video {
      max-width: 100%; }
    #sysadmin .archive li {
      margin-top: 1em; }
    #sysadmin .char {
      text-align: left; }
      #sysadmin .char dt:after {
        content: ":"; }
      #sysadmin .char dd:after {
        content: "\A";
        white-space: pre; }
      #sysadmin .char dd {
        margin-left: 0em; }
      #sysadmin .char dt, #sysadmin .char dd {
        display: inline;
        white-space: pre; }
      #sysadmin .char img {
        margin: 1em; }
      #sysadmin .char p {
        text-indent: 1em; } }
  @media screen and (min-width: 1024px) {
    #sysadmin figure {
      padding: 1em; }
    #sysadmin .cominavbox, #sysadmin .cominavbox li {
      margin-left: 1em;
      margin-right: 1em;
      margin-bottom: 0em; }
    #sysadmin figure + .cominavbox {
      margin-top: 0em; }
    #sysadmin nav li {
      padding: 1em;
      margin: 0em; }
    #sysadmin .archive {
      margin: 1em;
      padding: 1em; }
      #sysadmin .archive h2 {
        margin: 0em 0em 1em 0em; }
    #sysadmin main > div, #sysadmin main > section {
      margin: 1em; }
      #sysadmin main > div h2, #sysadmin main > section h2 {
        margin-top: 0em; }
    #sysadmin img, #sysadmin embed, #sysadmin object, #sysadmin video {
      max-width: auto; }
    #sysadmin .main {
      padding: 1em; }
    #sysadmin .intro {
      border: none;
      margin: 0em;
      padding: 0em;
      text-align: left; }
      #sysadmin .intro h2 {
        margin-bottom: 0.5em; }
      #sysadmin .intro img {
        display: inline; }
      #sysadmin .intro .author {
        font-weight: bold; }
      #sysadmin .intro .desc {
        font-weight: bold; }
    #sysadmin .main, #sysadmin .intro {
      text-align: left; }
      #sysadmin .main p, #sysadmin .intro p {
        text-align: left;
        margin: 1em; } }

/*# sourceMappingURL=style.css.map */
