@import "gradient.scss";
@media screen {
/*City*/
    #city {
    /*Blues*/
    /*$bg: #3161D0;*/
    $bg: #24489d;
    $vbg: #1d397a;
    $bc: #3A8CDE;
    $borders: #375490;
    /*Purples*/
    $bgn: #5923a9;
    $bcn: #9581f8;
    $vbgn: #2b1152;
    $moon: #DA8DD3;
    /*Accents*/
    $city: #00d3dc;
    $c: #00edf5;
    $vc: #99ffff;
    $twinkle: #ddff77;
    $t: #ECFFB3;
    $vt: #ccffcc;
    /* Default (small) screens */
        * {
            box-sizing: content-box;
        }
        body {
            background-color: $vbg;
            color: $vc;
            text-align: center;
            font-size: 1.5em;
            font-family: "Lato", "Noto Sans", "DejaVu Sans", sans-serif;
            margin: 0em;
        }
        
        header {
            margin: 0em;
        }
        
        footer {
            padding-top: 1em;
            margin-bottom: 0em;
            & p:last-of-type {
                margin-bottom: 0em
            }
        }

        main, figure {
            margin-left: 0em;
            padding-left: 0em;
        }
        
        main div, main section, figcaption, nav li, .cominavbox {
            background-color: $bg;
            color: $vt;
            border: solid thick $twinkle;
        }
        
        main div, main section {
            padding-left: 1em;
            padding-right: 1em;
            padding-bottom: 1em;
        }

        h1 {
            margin: 0em;
        }
        figure {
            padding: 0em;
            margin: 0em;
            border: none;
            background: none;
        }
        
        figcaption {
            padding: 1em;
        }
        
        .cominavbox, .cominavbox li {
            display: inline-block;
            padding: 0em;
            a, img {
                display: block;
            }
        }
        
        .cominavbox li img {
            padding: 0.5em;
        }
        
        .cominavbox li a:active, .cominavbox li a:focus {
            outline: dashed medium $moon;
        }

        main, p + p, li + li, div+div, section+section {
            margin-top: 0.5em
        }

        /*TODO: Fix the skip link hiding method*/
        #skippy {
            text-align: left;
            margin: 0em
        }
        #skippy a, #skippy a:hover, #skippy a:visited {
            position:absolute;
            left:-10000px;
            top:auto;
            width:1px;
            height:1px;
            overflow:hidden;
        }

        #skippy a:active, #skippy a:focus {
          position: static;
          height: auto;
          width: auto;
          font-size: 1em;
          margin-top: 0em;
          color: #fff;
        }

        nav ul {
            padding-left: 0em;
            li {
                display: inline-block;
                padding: 0.5em;
            }
        }

        main div, main section {
            text-align: left;
        }

        .statline {
            font-weight: bold;
        }

        a:link, a:visited {
            color: $t;
            text-decoration: underline
        }

        a:hover {
            text-decoration: underline
        }

        a:hover, a:focus, a:active {
            color: $vc;
        }

        footer p {
            margin-left: 0em;
            text-align: left;
        }

        .archive {
            vertical-align: top;
            text-align: left;
        }

        img, embed, object, video {
            max-width: 100%;
        }

        .action {
            font-weight: bold;
        }

        .charname {
            font-weight: bold
        }
        
        .intro, .chartext {
            border: none;
        }
        
        .char {
            text-align: left;
            dt:after {
                content: ":"
            };
            dd:after {
                content: "\A"; white-space: pre;
            };
            dd {
                margin-left: 0em;
            };
            dt, dd {
                display: inline;
                white-space: pre;
            };
            dt {
                font-weight: bold;
            };
            dl {
                font-size: 0.9em;
            };
            img {
                margin: 1em;
            };
        }

    /*Medium screens*/

        @media screen and (min-width: 1024px) {
            body {
                background-color: $vbg;
                background: url("skyline.png");
            }

            figure {
                margin-left: 1em;
                margin-top: 0em;
                margin-bottom: 0em;
                padding: 1em;
                width: 70%;
            }
            
            header {
                background-color: $vbg;
                background: $vbg url("moon.png") no-repeat 95% 95%;
                h1 {
                    padding-bottom: 1em;
                    margin-bottom: 1em;
                }
            }

            main {
                text-align: left;
                div, section {
                    padding-left: 1em;
                    padding-right: 1em;
                    width: 80%;
                    margin: 1em;
                    h2 {
                        background: url("5check.png") repeat-x 0% 100%;
                        margin-bottom: 0.5em;
                        padding-bottom: 0.5em;
                    }
                }
            }

            .cominavbox {
                margin: 0em 0em 0em 1em;
                padding: 1em;
                li {
                    margin-top: 0em;
                    margin-right: 1em;
                    margin-bottom: 0em;
                    margin-left: 1em;
                }
            }

            figure {
                margin-left: 1em;
            }

            h1 {
                font-size: 1.6em;
            }

            h2 {
                font-size: 1.3em;
            }

            nav li {
                padding-top: 1em;
                padding-left: 1em;
                padding-right: 1em;
                padding-bottom: 0.8em;
                margin: 0em;
            }

            .statline {
                font-size: 0.8em;
                text-align: right;
            }

            footer {
                background: $vbg;
                margin-top: 1em;
                p {
                    font-size: 0.7em;
                    margin-left: 0.5em;
                }
            }
            
            .action {
                text-indent: 1em;
                font-weight: bold;
            }

            .archive {
                margin: 1em;
                padding-left: 1em;
                padding-right: 1em;
            }
            
            .main {
                padding: 0.5em;
                margin: auto;
                width: 50%;
                text-align: left;
                & p {
                    margin-left: 0em;
                };
                .author {
                    text-indent: 2em;
                }
            }
            
            .intro {
                border: none;
                margin: 0em 0.2em 0em 0.2em;
                padding: 0em 0.2em 0em 0.2em;
                width: 90%;
                h2 {
                    margin-top: 0em;
                    margin-left: 0em;
                };
            }
            .chartext {
                margin: 0em;
                &, .char img {
                    display: inline-block;
                    vertical-align: top;
                    max-width: 60%
                }
            }
        }
    }
}
