@media screen {
/*Gothic*/
    #gothic {
    $readable: #b7f;
    $accent: #e00;
    $bg-color: #100;
    /* Default (small) screens */
        * {
            box-sizing: content-box;
        }
        body {
            background-color: $bg-color;
            color: $readable;
            text-align: center;
            font-size: 1.5em;
            font-family: serif;
            margin: 0em;
        }
        
        img, embed, object, video {
            max-width: 100%;
        }

        main, figure {
            margin-left: 0em;
            padding-left: 0em;
        }
        figure#comic {
            padding: 0em;
            text-align: center;
            border: none;
        }

        /*TODO: Fix the skip link hiding method*/
        #skippy {
            text-align: left;
            margin: 0em
        }
        #skippy a, #skippy a:hover, #skippy a:visited {
            position:absolute;
            left:-10000px;
            top:auto;
            width:1px;
            height:1px;
            overflow:hidden;
        }

        #skippy a:active, #skippy a:focus {
          position: static;
          height: auto;
          width: auto;
          font-size: 1em;
          margin-top: 0em;
          color: #0000ff;
        }
        
        nav {
            & ul {
                padding-left: 0em;
            }
            & li {
                display: inline-block;
                & + li {
                    border-left: solid thin $accent;
                    padding-left: 0.5em;
                }
            }
        }


        #commentary, #transcript {
            text-align: left;
        }

        .statline {
            font-weight: bold;
        }

        a:link {
            color: #3e9fff;
            text-decoration: underline
        }

        a:visited {
            color: #a78ae2;
        }

        a:hover {
            text-decoration: underline
        }

        a:hover, a:focus, a:active {
            color: #f77;
        }

        footer p {
            margin-left: 0em;
            text-align: left;
        }

        .archive {
            vertical-align: top;
            text-align: left;
        }
        
        .cominavbox {
            margin: 0em;
            padding: 0em;
            & li {
                display: inline-block;
                padding: 0.5em;
                margin: 0em
            }
        }

        .action {
            font-weight: bold;
        }
        
        p + p, li + li, div + div {
            margin-top: 0.5em;
        }
            
        main div, .archive {
            border: double medium $accent;
            border-left: none;
            border-right: none;
        }
        
        h1 {
            margin: 0em;
            margin-bottom: 1em;
        }
        
        .char {
            text-align: left;
            dt:after {
                content: ":"
            };
            dd:after {
                content: "\A"; white-space: pre;
            };
            dd {
                margin-left: 0em;
            };
            dt, dd {
                display: inline;
                white-space: pre;
            };
            dt {
                font-weight: bold;
            };
            dl {
                font-size: 0.9em;
            };
            img {
                margin: 1em;
                border: double medium $accent;
            };
            p {
                text-indent: 1em;
            }
        }

    /*Medium screens*/

        @media screen and (min-width: 1024px) {
            body {
                font-size: 1.5em;
                margin-left: 1em;
                background: url("drips.gif") fixed repeat-x 0% 0%, $bg-color url("rose-tall.gif") fixed no-repeat 100% 100%;
                margin: 0em;                
            }

            figure {
                margin-left: 1em;
                margin-top: 0em;
                margin-bottom: 0em;
            }

            main div, main section {
                padding-left: 1em;
                padding-right: 1em;
                width: 80%;
                margin-top: 1em;
            }

            .cominavbox {
                margin: 0em;
                padding: 1em;
            }

            .cominavbox li {
                margin: 0.5em 1em 0em 1em;
            }

            figure + .cominavbox {
                margin-top: 0em;
            }

            figure#comic {
                margin-left: 1em;
            }

            h1 {
                font-size: 1.5em;
            }

            h2 {
                font-size: 1.2em;
            }
            
            h3 {
                font-size: 1em;
            }

            .statline {
                font-size: 0.8em;
                text-align: right;
            }

            footer p {
                font-size: 0.7em;
            }

            .archive {
                margin-left: 1em;
                margin-right: 1em;
                padding-left: 1em;
                padding-right: 1em;
            }
            
            figure#comic, main div, .archive, nav li {
                border: double medium $accent;
                background: $bg-color;
            }
            
            nav li, nav li+li {
                border: none;
                border: double medium $accent;
                padding: 0em;
                padding: 0.5em
            }
            
            h2 {
                border-bottom: solid thin $accent
            }
            
            h1 {
                margin-bottom: 1em;
            }

            .action {
                text-indent: 1em;
            }
            
            .main {
                padding: 0.5em;
                margin: auto;
                margin-top: 1em;
                width: 50%;
                text-align: center;
                & p {
                    margin-left: 0em;
                }
            }
            
            .intro {
                border: none;
                margin: 0em;
                padding: 0em;
                text-align: left;
                & h2 {
                    margin-bottom: 0.5em;
                };
                & img {
                    display: inline;
                };
                & .author {
                    font-size: 0.8em;
                }
                & .desc {
                    font-weight: bold;
                }
            }
            
            .char {
                img {
                    margin: 0em 1em 1em 0em
                }
                .chartext {
                    margin: 0em
                }
                .chartext, img {
                    display: inline-block;
                    vertical-align: top;
                    max-width: 50%;
                }
            }

        }
    }
}