@media screen {
/*Haunted*/
    #haunted {

    $bbg: #181029;
    $mbg: #312845;
    $acc: #07000b;
    $lt: #ccc0d4;
    $aa: #a3c1fe;
    $av: #fab3ff;
    $ahaf: #6dd3d6;
    $anh: #fab3ff;*

    /* Default (small) screens */
        * {
            box-sizing: content-box;
        }
        body {
            background-color: $bbg;
            background-image: url("web2.png");
            background-position: 100% 0;
            background-repeat: no-repeat;
            background-attachment: fixed;
            color: $lt;
            text-align: center;
            font-size: 1.5em;
            font-family: serif;
            margin: 0em;
        }

        main, figure {
            margin-left: 0em;
            padding-left: 0em;
        }

        main div, main section, figure#comic, .archive {
            background-color: $mbg;
            padding-left: 0.5em;
            padding-right: 0.5em;
        }

        main div, main section, figure#comic, .archive, h1 {
            border: solid thick $acc;
            border-left: none;
            border-right: none;
        }
        
        div, section {
            background-image: url("bat.png");
            background-repeat: no-repeat;
            &#transcript, &.archive {
                background-position: 98% 98%;
            };
            &#commentary, &.main {
                background-position: 98% 5%;
            }
        }
        
        figure#comic {
            background-image: url("bat.png");
            background-repeat: no-repeat;
            background-position: 2% 99%;
        }
        
        nav li {
            border: solid thick $acc;
        }

        h1 {
            margin: 0em;
            margin-top: 1em;
            background-color: $mbg;
            padding: 1em;
            font-weight: normal;
        }
        figure#comic {
            padding: 1em 0em;
            margin: 1em 0em;
            text-align: center;
        }

        /*TODO: Fix the skip link hiding method*/
        #skippy {
            text-align: left;
            margin: 0em;
        }
        #skippy a, #skippy a:hover, #skippy a:visited {
            position:absolute;
            left:-10000px;
            top:auto;
            width:1px;
            height:1px;
            overflow:hidden;
        }

        #skippy a:active, #skippy a:focus {
          position: static;
          height: auto;
          width: auto;
          font-size: 1em;
          margin-top: 0em;
          color: #fff;
        }

        nav ul {
            padding-left: 0em;
        }

        nav li {
            display: inline-block;
            background-color: $mbg;
            padding: 0.5em;
            + li {
                margin-left: 0.5em;
            }
        }

        #commentary, #transcript {
            text-align: left;
        }

        .statline {
            font-weight: bold;
        }

        a:link {
            color: $aa;
            text-decoration: underline
        }

        a:visited {
            color: $av;
        }

        a:hover {
            text-decoration: underline
        }

        a:hover, a:focus, a:active {
            color: $ahaf;
        }

        a:focus, a:active {
            background: $bbg;
            outline: dashed medium $ahaf;
        }

        footer {
            margin-bottom: 0em;
            border-top: solid medium $mbg;
            p {
                margin-left: 0em;
                text-align: left;
                &:last-of-type {
                    margin-bottom: 0em
                }
            }
        }

        .archive {
            display: inline-block;
            vertical-align: top;
            text-align: left;
        }

        img, embed, object, video {
            max-width: 100%;
        }

        .action {
            font-weight: bold;
        }

        .cominavbox {
            display: inline-block;
            padding: 0em;
            margin: 0em 1em;
            a:focus, a:active {
                outline: medium dashed $ahaf;
            }
        }

        .cominavbox li {
            display: inline-block;
            margin: 0em;
            a:active, a:focus {
                display: block;
                outline: dashed medium $anh;
            };
            img {
                margin: 0em;
            }
        }
        
        figure + .cominavbox {
            margin-bottom: 1em;
            margin-top: 0em;
        }

        .char {
            text-align: center;
            background-image: none;
            dt:after {
                content: ":"
            };
            dd:after {
                content: "\A"; white-space: pre;
            };
            dd {
                margin-left: 0em;
            };
            dt, dd {
                display: inline;
                white-space: pre;
            };
            .chartext {
                margin: none;
                border: none;
            }
        }
        
        h2 {
            font-weight: normal;
            font-weight: bold;
        }

        * + * {
            margin-top: 1em
        }
        
        header {
            margin-top: 0em;
        }

        main {
            div, section {
                padding: 1em 0.5em;
            }
            .main, .allchars, .char {
                margin-top: 2em;
            }
        }

        .intro {
            border: none;
            background: none;
            margin: 0em;
            padding: 0 0;
            width: 100%;
            & img {
                display: inline;
                margin: 0em;
                padding: 0em;
            };
        }

        div + div, section + section {
            margin-top: 1em;
        }

    /*Medium screens*/

        @media screen and (min-width: 1024px) {
            body {
                margin: 0;
                padding-bottom: 0;
            }

            main div, main section, figure#comic, .archive, h1 {
                border: solid thick $acc;
            }

            figure {
                padding: 1em;
                margin: 0em 1em;
            }

            main {
                width: 80%;
                margin-left: 2em;
                margin-bottom: 2em;
            }

            main div, main section {
                margin-left: 1em;
                padding: 0.1rem 2rem 0.2rem 2rem;
                width: 80%;
            }

            h1 {
                font-size: 1.5em;
                max-width: 70%;
                margin: auto;
                margin-top: 1em;
                margin-bottom: 0em;
            }

            h2 {
                font-size: 1.2em;
            }

            h3 {
                font-size: 1em;
            }

            nav li {
                padding: 1em 1em 0.8em 1em;
                margin: 0em;
                & + li {
                    margin-left: 1em;
                }
            }
            
            .cominavbox li {
                margin: 0em 1em;
                max-width: 100%;
            }

            .statline {
                font-size: 0.8em;
                text-align: right;
            }

            footer {
                margin: 1em 0em 0em 0em;
                padding: 0.2em;
                & p {
                    font-size: 0.7em;
                    text-align: left;
                    margin-left: 0.5em;
                }
            }
            
            .action {
                text-indent: 1em;
            }

            .archive {
                margin: 1em;
                padding-left: 1em;
                padding-right: 1em;
                width: 90%;
            }

            .main {
                padding: 0.5em;
                margin: auto;
                margin-top: 2em;
                width: 80%;
                text-align: left;
                & p {
                    margin-left: 0.5em;
                }
            }

            .intro {
                margin: 0em;
            }

            .intro + .intro {
                border-top: dashed thin $bbg;
            }

            .char {
                padding: 0em;
                img {
                    margin: 0em 1em 1em 0em
                }
                .chartext {
                    margin: 0em;
                    text-align: left
                }
                .chartext, img {
                    display: inline-block;
                    vertical-align: top;
                    max-width: 50%;
                }
            }

        }
    }
}
