@media screen {
/*Showtime*/
    #showtime {
    $text: #d9d9d9;
    $bg: #171717;
    /* Default (small) screens */
        * {
            box-sizing: content-box;
        }
        body {
            background-color: $bg;
            background: $bg url("curtaint.png") repeat-x 0% 0%;
            color: $text;
            text-align: center;
            font-size: 1.5em;
            font-family: sans-serif;
            display: grid;
            grid-gap: 1em;
            grid-template-areas:
              'skip'
              'header'
              'main'
              'footer';
            grid-template-columns: auto;
        }
        #skippy {
          grid-area: skip;
        }
        
        header {
          grid-area: header;
        }
        
        main {
          grid-area: main;
        }
        
        footer {
          grid-area: footer;
        }

        main, figure {
            margin-left: 0em;
            padding-left: 0em;
        }

        h1 {
            margin: 0em;
        }
        figure#comic {
            padding: 1em;
            text-align: center;
        }
        .cominavbox, .cominavbox li {
            display: inline-block;
            padding: 0em;
        }

        p + p, li + li {
            margin-top: 0.5em
        }

        /*TODO: Fix the skip link hiding method*/
        #skippy {
            text-align: left;
        }
        #skippy a, #skippy a:hover, #skippy a:visited {
            position:absolute;
            left:-10000px;
            top:auto;
            width:1px;
            height:1px;
            overflow:hidden;
        }

        #skippy a:active, #skippy a:focus {
          position: static;
          height: auto;
          width: auto;
          font-size: 1em;
          margin-top: 0em;
          color: #0000ff;
        }

        nav li {
            display: inline-block;
        }

        #commentary, #transcript {
            text-align: left;
        }

        .statline {
            font-weight: bold;
        }

        a:link {
            color: #9E9EFF;
            text-decoration: underline
        }

        a:visited {
            color: #C38FFF;
        }

        a:hover {
            text-decoration: underline
        }

        a:hover, a:focus, a:active {
            color: #FF8585;
        }

        footer p {
            margin-left: 0em;
            text-align: left;
        }

        .archive {
            display: inline-block;
            vertical-align: top;
            text-align: left;
        }

        img, embed, object, video {
            max-width: 100%;
        }

        .action {
            font-weight: bold;
        }

        .charname {
            font-weight: bold
        }
        
        .char {
            dt:after {
                content: ":"
            }
            dd:after {
                content: "\A"; white-space: pre;
            }
            dd {
                margin-left: 0em;
            }
            dt, dd {
                display: inline;
                white-space: pre;
            }
        }

    /*Medium screens*/

        @media screen and (min-width: 1024px) {
            body {
                margin: 0em;
                background: url("curtaint.png") repeat-x 0% 0%, url("curtainr.png") fixed repeat-y 100% 0%, $bg url("curtainl.png") fixed repeat-y 0% 0%;
            }

            figure#comic {
                margin-left: 1em;
                margin-top: 0em;
                margin-bottom: 0em;
                img {
                  border: 1em solid #A06D3D
                }
            }
            figure#comic figcaption {
              max-width: 80%;
              margin: auto;
            }

            main div, main section {
                text-align: left;
                padding-left: 1em;
                padding-right: 1em;
                width: 70%;
                margin: auto;
            }

            div + div {
                margin-bottom: 0em;
                margin-top: 0em;
            }

            .cominavbox, .cominavbox li {
                margin-left: 1em;
                margin-right: 1em;
                margin-top: 0.5em;
                margin-bottom: 0em;
            }

            figure + .cominavbox {
                margin-top: 0em;
            }

            figure {
                margin-left: 1em;
            }

            h1 {
                font-size: 1.5em;
            }

            h2 {
                font-size: 1.2em;
            }
            
            h3 {
                font-size: 1em;
            }

            nav li {
                padding-top: 1em;
                padding-left: 1em;
                padding-right: 1em;
                padding-bottom: 0.8em;
                margin: 0em;
            }

            .statline {
                font-size: 0.8em;
                text-align: right;
            }

            footer {
              background: $bg;
              margin: 0em;
              padding: 0.5em;
            }

            footer p {
                font-size: 0.7em;
                margin-bottom: 0em;
            }

            .archive {
                margin-left: 0em;
                margin-right: 1em;
                padding-left: 1em;
                padding-right: 1em;
            }
            
            .main {
                padding: 0.5em;
                margin: auto;
                width: 50%;
                & p {
                    margin-left: 0em;
                }
            }
            .char {
                text-align: left;
            }
            .chartext, .charimg {
              display: inline-block;
              vertical-align: top
            }
        }
    }
}
