@media screen {
  /*Might*/
  #might {
    /* Default (small) screens */
    /*TODO: Fix the skip link hiding method*/
    /*Medium screens*/ }
    #might * {
      box-sizing: content-box; }
    #might body {
      background-color: #000022;
      color: #fff;
      text-align: center;
      font-size: 1.5em;
      font-family: sans-serif;
      margin: 0em;
      display: grid;
      grid-gap: 0em;
      grid-template-areas: 'skip' 'head' 'main' 'footer'; }
    #might header {
      margin: 0em;
      grid-area: head;
      background-color: #ffed00; }
    #might footer {
      grid-area: footer;
      padding: 0.5em;
      background: #000022;
      margin: 0em; }
    #might main {
      grid-area: main; }
    #might main, #might figure {
      margin-left: 0em;
      padding-left: 0em; }
    #might main div, #might main section, #might figcaption, #might nav li, #might .cominavbox {
      background-color: #000022;
      color: #fff;
      border: solid thick #ff0042; }
    #might main div, #might main section {
      padding: 0em 1em; }
    #might h1 {
      margin: 0em; }
    #might figure {
      padding: 0em;
      margin: 0em;
      border: none;
      background: none;
      text-align: center; }
    #might figcaption {
      padding: 1em;
      border: none; }
    #might .cominavbox, #might .cominavbox li {
      display: inline-block;
      text-align: center;
      padding: 0em; }
    #might li + li, #might div + div, #might section + section {
      margin-top: 0.5em; }
    #might .cominavbox li {
      padding: 0.5em;
      text-align: center; }
      #might .cominavbox li a {
        line-height: 1rem; }
    #might figure + .cominavbox {
      margin-bottom: 1em; }
    #might #skippy {
      grid-area: skip;
      text-align: left;
      margin: 0em; }
    #might #skippy a, #might #skippy a:hover, #might #skippy a:visited {
      position: absolute;
      left: -10000px;
      top: auto;
      width: 1px;
      height: 1px;
      overflow: hidden; }
    #might #skippy a:active, #might #skippy a:focus {
      position: static;
      height: auto;
      width: auto;
      font-size: 1em;
      margin-top: 0em;
      background: #000;
      color: #fff; }
    #might nav ul {
      padding-left: 0em; }
      #might nav ul li {
        display: inline-block;
        padding: 0.5em; }
    #might main div, #might main section {
      text-align: left; }
    #might .statline {
      font-weight: bold; }
    #might a:link {
      color: #6694FF;
      text-decoration: underline; }
    #might a:visited {
      color: #D480FF; }
    #might a:hover {
      text-decoration: underline; }
    #might a:hover, #might a:focus, #might a:active {
      color: #FF7A7A; }
    #might footer p {
      margin-left: 0em;
      text-align: left; }
    #might .archive {
      vertical-align: top;
      text-align: left; }
    #might img, #might embed, #might object, #might video {
      max-width: 100%; }
    #might .action {
      font-weight: bold; }
    #might .charname {
      font-weight: bold; }
    #might .intro, #might .chartext {
      border: none; }
    #might .char {
      text-align: left; }
      #might .char dt:after {
        content: ":"; }
      #might .char dd:after {
        content: "\A";
        white-space: pre; }
      #might .char dd {
        margin-left: 0em; }
      #might .char dt, #might .char dd {
        display: inline;
        white-space: pre; }
      #might .char dt {
        font-weight: bold; }
      #might .char dl {
        font-size: 0.9em; }
      #might .char img {
        margin: 1em; }
    #might .char img, #might .chartraits {
      margin: 0em;
      padding: 0em; }
    #might .chartext {
      border: none;
      padding: 0em;
      margin: 0em;
      line-height: 2em; } }
  @media screen and (min-width: 1024px) {
    #might figure#comic {
      margin-left: 1em;
      margin-top: 0em;
      margin-bottom: 0em;
      padding: 1em; }
    #might header {
      background-color: #ffed00;
      background: radial-gradient(circle at bottom center, #ffed00 85%, #A5032C 86%); }
      #might header h1 {
        margin-bottom: 1em;
        color: black; }
    #might main {
      background-color: #ffed00;
      background: url("skyline.png"), linear-gradient(to bottom, #ffed00 0%, #A5032C 50%);
      padding: 0.5em; }
      #might main div, #might main section {
        width: 80%;
        text-align: left; }
        #might main div h2, #might main section h2 {
          border-bottom: solid thick #ffed00;
          margin-top: 0em; }
    #might .cominavbox {
      margin: 0em 0em 0em 1em;
      padding: 1em; }
      #might .cominavbox li {
        margin: 0em 1em; }
    #might h1 {
      font-size: 1.6em; }
    #might h2 {
      font-size: 1.3em; }
    #might nav li {
      padding-top: 1em;
      padding-left: 1em;
      padding-right: 1em;
      padding-bottom: 0.8em;
      margin: 0em; }
    #might .statline {
      font-size: 0.8em;
      text-align: right; }
    #might footer {
      background: #000022; }
    #might .action {
      text-indent: 1em;
      font-weight: bold; }
    #might .archive {
      margin: 1em;
      padding-left: 1em;
      padding-right: 1em; }
    #might .main {
      padding: 0.5em;
      margin: auto;
      text-align: left;
      width: 80%; }
      #might .main p {
        margin-left: 0em; }
      #might .main .author {
        text-indent: 2em; }
    #might .intro {
      border: none;
      margin: 0em;
      padding: 1em;
      width: auto; }
      #might .intro h2 {
        margin-top: 0em;
        margin-left: 0em; }
    #might .char {
      text-align: left; }
      #might .char img {
        border: solid medium #375490; }
      #might .char img, #might .char .chartraits {
        display: inline-block;
        vertical-align: top; }
      #might .char .chartext {
        width: auto; }
    #might .chartraits {
      margin-left: 1em; }
    #might .chartraits * {
      line-height: 1.5em; } }

/*# sourceMappingURL=style.css.map */
