@media screen {
/*Fantasy*/
    #fantasy {
    /* Default (small) screens */
        * {
            box-sizing: content-box;
        }
        body {
            background-color: #314e30;
            background-image: url(leaves.jpg);
            color: #eee;
            text-align: center;
            font-size: 1.5em;
            font-family: serif;
            margin: 0em;
        }
        
        nav li, figure, main div, main section, .cominavbox {
            background-color: #f5ebda;
            background-image: url(paper.gif);
            color: #222;
            border: thick ridge gold;
        }

        h1 {
            margin: 0em;
        }        
        
        figure {
            text-align: center;
        }
        .cominavbox, .cominavbox li {
            display: inline-block;
            padding: 0em;
        }
        
        .cominavbox li {
            a:active, a:focus {
                display: block;
                outline: dotted thick #e41f1f;
            };
        }

        p + p, li + li {
            margin-top: 0.5em
        }

        /*TODO: Fix the skip link hiding method*/
        #skippy {
            text-align: left;
        }
        #skippy a, #skippy a:hover, #skippy a:visited {
            position:absolute;
            left:-10000px;
            top:auto;
            width:1px;
            height:1px;
            overflow:hidden;
        }

        #skippy a:active, #skippy a:focus {
          position: static;
          height: auto;
          width: auto;
          font-size: 1em;
          margin-top: 0em;
          color: #fff;
        }

        nav li {
            display: inline-block;
            padding: 0.5em;
        }

        #commentary, #transcript {
            text-align: left;
        }

        .statline {
            font-weight: bold;
        }

        a:link {
            color: #eeeeff;
            text-decoration: underline
        }

        a:visited {
            color: #ffeeff;
        }

        a:hover {
            text-decoration: underline
        }

        a:hover, a:focus, a:active {
            color: #ffdddd;
        }
        
        main div, main section {
            h2, h3, h4 {
                border-bottom: thin solid goldenrod;
            }
        }
        
        nav, main {
            a:link {
                color: #181347;
            }

            a:visited {
                color: #441347;
            }

            a:hover, a:focus, a:active {
                color: #910c26;
            }
        }

        footer p {
            margin-left: 0em;
            text-align: left;
        }

        .archive {
            display: inline-block;
            vertical-align: top;
            text-align: left;
        }

        img, embed, object, video {
            max-width: 100%;
        }

        .action {
            font-weight: bold;
            text-indent: 1em;
        }

        .charname {
            font-weight: bold
        }
        
        .char {
            dt:after {
                content: ":"
            }
            dd:after {
                content: "\A"; white-space: pre;
            }
            dd {
                margin-left: 0em;
            }
            dt, dd {
                display: inline;
                white-space: pre;
            }
            img {
                border: thick ridge gold;
                margin: 0em;
            }
            .chartext {
                margin: 0em;
            }
        }

        main, figure {
            margin-left: 0em;
            padding-left: 0em;
            margin-right: 0em;
            padding-right: 0em;
            border-left: none;
            border-right: none;
            section, div {
                border-left: none;
                border-right: none;
                padding: 0.5em;
                & + div, & + section {
                    margin-top: 1em;
                }
            }
        }
            
        .intro {
            border: none;
            margin: 0em;
            padding: 0em;
        }

    /*Medium screens*/

        @media screen and (min-width: 1024px) {
    
            nav li, figure, main div, main section {
                border: thick ridge gold;
            }

            figure {
                margin: 0em 1em;
                padding: 1em;
            }

            main div, main section {
                padding: 0.5em 1em;
                margin: 1em;
                width: 80%;
                margin-top: 1em;
                h2 {
                    margin-top: 0.5em;
                    background-image: url(gem.png);
                    background-size: contain;
                    background-position: 100% 100%;
                    background-repeat: no-repeat;
                }
            }

            div + div {
                margin-bottom: 0em;
                margin-top: 0em;
            }

            .cominavbox, .cominavbox li {
                margin-left: 1em;
                margin-right: 1em;
                margin-top: 0.5em;
                margin-bottom: 0em;
            }

            figure + .cominavbox {
                margin-top: 0em;
            }

            figure {
                margin-left: 1em;
            }

            h1 {
                font-size: 1.5em;
            }

            h2 {
                font-size: 1.2em;
            }
            
            h3 {
                font-size: 1em;
            }

            nav li {
                padding-top: 1em;
                padding-left: 1em;
                padding-right: 1em;
                padding-bottom: 0.8em;
                margin: 0em;
            }

            .statline {
                font-size: 0.8em;
                text-align: right;
            }

            footer p {
                font-size: 0.7em;
                margin-left: 1em;
            }

            .archive {
                margin-left: 1em;
                margin-right: 1em;
                padding-left: 1em;
                padding-right: 1em;
            }
            
            .main {
                padding: 0.5em;
                margin: auto;
                width: 50%;
                text-align: center;
                & p {
                    margin-left: 0em;
                }
            }
            .char {
                text-align: left;
                img {
                    margin: 0em 1em 0em 0em
                }
                .chartext, img {
                    display: inline-block;
                    vertical-align: top;
                    max-width: 60%;
                }
            }
        }
    }
}
