@import "shadow.scss";
@import "gradient.scss";
@media screen {
/*Two Thousand*/
    #twothousand {

    $bg-color: #222262;
    $accent-color: #ffb326;
    /*$accent-color: #800;*/
    $head-color:  #2b2b2b;
    $borders: #7f7f7f;
    /* Default (small) screens */
        * {
            box-sizing: content-box;
        }
        body {
            background-color: $head-color;
            color: #111;
            text-align: center;
            font-size: 1.5em;
            font-family: sans-serif;
            margin: 0;
        }

        main, figure {
            margin-left: 0em;
            padding-left: 0em;
        }

        h1 {
            margin: 0em;
        }

        figure {
            padding: 0em;
            margin-left: 0em;
            margin-right: 0em;
            text-align: center;
            & img {
                margin: 0em;
            }
        }

        figcaption {
            margin-top: 0.5em;
            margin-bottom: 0.5em;
            padding: 0em
        }
        .cominavbox, .cominavbox li {
            display: inline-block;
            padding: 0em;
            a {
                outline-width: medium;
                outline-color: #ffb300;
            }
        }

        p + p, li + li {
            margin-top: 0.5em
        }

        /*TODO: Fix the skip link hiding method*/
        #skippy {
            text-align: left;
            margin: 0em
        }
        #skippy a, #skippy a:hover, #skippy a:visited {
            position:absolute;
            left:-10000px;
            top:auto;
            width:1px;
            height:1px;
            overflow:hidden;
        }

        #skippy a:active, #skippy a:focus {
          position: static;
          height: auto;
          width: auto;
          font-size: 1em;
          margin-top: 0em;
          color: #bbf;
          margin: 1em;
          outline: dotted medium #bbf
        }

        nav, h1, h2, h3 {
            background: $accent-color;
            @include linear-gradient(#ffffcc,$accent-color);
            border: solid thin $borders;
            border-left: none;
            border-right: none;
            color: #222;
        }

        nav {
            margin-bottom: 0em;
            text-align: center;
            & ul {
                margin-bottom: 0em;
                margin-top: 0em;
            }
            & li {
                display: inline-block;
            }
            & li + li {
                margin-left: 1em;
            }
            & a:link {
                text-decoration: none
            }
            & a:hover {
                text-decoration: underline
            }
        }

        header {
            margin-top: 0em;
            padding-top: 0em;
            width: 100%;
            & img {
                margin: 0em;
                padding: 0em;
            }
        }

        main {
            /*background: #ddd;*/
            background: $bg-color;
            color: #eee;
            border: solid thin $borders;
            border-left: none;
            border-right: none;
            & div {
                text-align: left;
            }
        }

        .statline {
            font-weight: bold;
        }

        a:link {
            color: #0000c1;
            text-decoration: underline
        }

        a:visited {
            color: #46284c;
        }

        a:hover, a:focus, a:active {
            color: #700404;
        }
        
        main a {
            &:link {
                color: #abbdee
            }
            &:visited {
                color: #daadf0
            }
            &:hover, &focus, &:active {
                color: #eeaeb6
            }
        }

        footer {
            color: #ffd;
            & a:link {
                color: #bbf;
                text-decoration: underline
            }
            & a:visited {
                color: #daf;
            }
            & a:hover, & a:focus, & a:active {
                color: #ffaaaa;
            }
            & p {
                margin-left: 0em;
                text-align: left;
            }
        }

        .archive {
            vertical-align: top;
            text-align: left;
            h2 {
                border: none;
                background: none;
                margin-top: 0.5em;
                color: inherit;
            };
            h3 {
                border: none;
                background: none;
                margin-left: 1em;
                margin-top: 0em;
                color: inherit;
            };
            & ol {
                margin-top: 0em;
                margin-left: 1em;
            }
        }

        img, embed, object, video {
            max-width: 100%;
        }

        .action {
            font-weight: bold;
        }
        
        .char {
            text-align: left;
            dt:after {
                content: ":"
            };
            dd:after {
                content: "\A"; white-space: pre;
            };
            dd {
                margin-left: 0em;
            };
            dt, dd {
                display: inline;
                white-space: pre;
            };
        }
        
        .status {
            text-indent: 2em;
            font-size: .9em;
            font-weight: bold;
            margin-top: 0em;
        }
        
        .char:first-of-type h2 {
            border-top: none;
            margin-top: 0em
        }

    /*Medium screens*/

        @media screen and (min-width: 640px) {
            body {
                font-size: 1.5em;
            }

            figure {
                padding: 1em 1em 0em 1em;
                margin-left: 1em;
                margin-top: 0em;
                margin-bottom: 0em;
                & + .cominavbox {
                    margin-top: 0em;
                }
            }

            nav, h1, h2, h3, main {
                border: solid thin $borders;
            }

            main {
                & div {
                    padding-left: 0em;
                    padding-right: 0em;
                    margin: 1em 0em 1em 0em;
                    & p {
                        margin-left: 1em
                    }
                }
            }

            div + div {
                margin-bottom: 0em;
                margin-top: 0em;
            }

            .cominavbox, .cominavbox li {
                margin: 0.5em 1em 0em 1em;
            }

            h1 {
                font-size: 1.5em;
                border-bottom: none;
                border-top: none;
                padding-top: 0.5em;
                padding-bottom: 0.5em;
                text-align: center;
            }

            h2 {
                font-size: 1.2em;
                margin: 0em;
                padding: 0.5em 0em 0.5em 0.5em;
                border-left: none;
                border-right: none
            }
            
            h3 {
                font-size: 1em;
            }
            
            header {
                margin-left: 1em;
            }

            nav {
                text-align: right;
                font-size: 1rem;
            }

            nav li {
                padding: 1em 1em 0.8em 1em;
                margin: 0em;
                & + li {
                    border-left: solid thin $borders;
                    margin-left: 0em;
                }
            }

            .statline {
                font-size: 0.8em;
                text-align: right;
                margin-right: 1em
            }

            footer p {
                font-size: 0.7em;
                margin-left: 1em
            }

            h1, main, nav {
                width: auto;
                margin-right: 1em;
                max-width: 80%;
            }
            
            header {
                text-align: left;
                max-width: 100%;
                margin-left: 0em;
            }
            
            header img {
                max-width: 90%;
                margin: 0em;
            }
            
            nav, h1 {
                margin-left: 0em;
            }
            
            nav {
                ul {
                    padding-inline-start: 0em;
                }
            }
            
            .main {
                padding: 0em;
                margin: 0em;
                width: 100%;
                & p {
                    margin-left: 0em;
                }
            }
            
            .intro {
                padding: 0em;
                margin: 0em;
                width: 100%;
                .author {
                    font-weight: bold;
                }
                .desc {
                    font-size: .8em;
                    text-indent: 1em;
                }
                h2 {
                    border-top: none;
                    text-align: center;
                }
                p {
                    padding: 0em 1em 1em 1em;
                }
            }
            
            .char {
                padding: 0em;
                img {
                    margin: 0em 1em 1em 0em
                }
                .chartext {
                    margin: 0em;
                    text-align: left
                }
                .chartext, img {
                    display: inline-block;
                    vertical-align: top;
                    max-width: 70%;
                }
                &:first-of-type {
                    margin-top: 0em;
                    h2 {
                        border-top: none;
                        margin-top: 0em
                    }
                }
            }
    }


    /*Larger screens*/

        @media screen and (min-width: 1280px) {

            nav {
                font-size: 1em;
            }

            h1, main, nav {
                width: auto;
                margin-right: 1em;
                max-width: 70%;
            }
        }
    }
    
}
