@media screen {
/*Revolution*/
    $bg: #060606;
    $text: lavenderblush;
    $lac: #e7568d;
    #revolution {
    /* Default (small) screens */
        * {
            box-sizing: content-box;
        }
        body {
            background-color: $bg;
            background: $bg url("sparks.png") top left fixed no-repeat;
            color: $text;
            text-align: center;
            font-size: 1.5em;
            font-family: sans-serif;
            margin: 0em;
        }

        main, figure {
            margin: 0em;
            padding-left: 0em;
            padding-right: 0em;
        }

        h1 {
            margin: 0em;
        }
        figure {
            text-align: center;
            border: none;
        }
        .cominavbox, .cominavbox li {
            display: inline-block;
            padding: 0em;
        }

        p + p, li + li {
            margin-top: 0.5em
        }

        /*TODO: Fix the skip link hiding method*/
        #skippy {
            text-align: left;
        }
        #skippy a, #skippy a:hover, #skippy a:visited {
            position:absolute;
            left:-10000px;
            top:auto;
            width:1px;
            height:1px;
            overflow:hidden;
        }

        #skippy a:active, #skippy a:focus {
          position: static;
          height: auto;
          width: auto;
          font-size: 1em;
          margin-top: 0em;
          color: #0000ff;
        }

        nav li {
            display: inline-block;
        }

        #commentary, #transcript {
            text-align: left;
        }

        .statline {
            font-weight: bold;
        }

        a:link {
            color: #3e9fff;
            text-decoration: underline
        }

        a:visited {
            color: #a78ae2;
        }

        a:hover {
            text-decoration: underline
        }

        a:hover, a:focus, a:active {
            color: #f77;
        }

        footer p {
            margin-left: 0em;
            text-align: left;
        }

        .archive {
            display: inline-block;
            vertical-align: top;
            text-align: left;
        }

        img, embed, object, video {
            max-width: 100%;
        }

        .action {
            font-weight: bold;
        }
        
        .char {
            text-align: left;
            dt:after {
                content: ":"
            }
            dd:after {
                content: "\A"; white-space: pre;
            }
            dd {
                margin-left: 0em;
            }
            dt, dd {
                display: inline;
                white-space: pre;
            }
        }

        .charname {
            font-weight: bold;
        }
        
        .char img {
          margin: 0em;
          padding: 0em;
        }
        
        .chartraits {
          margin: 0em;
          padding: 0em;
        }
        
        .chardesc {
          border: none;
          padding: 0em;
          margin: 0em;
          line-height: 2em;
        }

    /*Medium screens*/

        @media screen and (min-width: 1024px) {
            body {
              background-color: $bg;
              background: $bg url("sparks.png") bottom right fixed no-repeat;
            }
            figure {
                margin-left: 1em;
                margin-top: 0em;
                margin-bottom: 0em;
            }

            main div, main section {
                padding: 2em 3em;
                width: 80%;
            }

            div + div {
                margin-bottom: 0em;
                margin-top: 1em;
            }

            .cominavbox, .cominavbox li {
                margin-left: 1em;
                margin-right: 1em;
                margin-top: 0.5em;
                margin-bottom: 0em;
            }

            figure + .cominavbox {
                margin-bottom: 1em;
            }

            figure#comic, main div, main section {
                background: $bg;
                border: solid thick $lac;
                border-image-slice: 68 66 70 64;
                border-image-width: 48px 48px 48px 48px;
                border-image-outset: 0px 0px 0px 0px;
                border-image-repeat: repeat repeat;
                border-image-source: url("rose_frame.png");
              }
              
              figure {
                padding: 0em 2em 2em 2em;
                &#comic {
                padding-top: 2em;
                margin-top: 1em;
                margin-left: 2em;
                margin-right: 2em;
                }
              }
              
              .intro {
                border: none;
                margin: 1em;
                padding: 1em;
                & + .intro {
                  padding-top: 0em;
                  margin-top: 0em;
                }
              }
              
              figcaption {
                  padding-left: 2em;
                  padding-right: 2em;
              }

            h1 {
                font-size: 1.5em;
            }

            h2 {
                font-size: 1.2em;
            }
            
            h3 {
                font-size: 1em;
            }

            nav li {
                padding-top: 1em;
                padding-left: 1em;
                padding-right: 1em;
                padding-bottom: 0.8em;
                margin: 0em;
            }

            .statline {
                font-size: 0.8em;
                text-align: right;
            }

            footer p {
                font-size: 0.7em;
            }

            .archive {
                padding: 1em 2em;
                margin: 1em;
            }
            
            .main {
                padding: 1em 2em;
                margin: 1em;
                text-align: left;
                & p {
                    margin-left: 0em;
                }
            }
            .char {
                text-align: left;
                img, .chartraits {
                    display: inline-block;
                    vertical-align: top;
                }
            }
            .chartraits {
                margin-left: 1em;
            }
            .chartraits * {
                line-height: 1.5em
            }
        }
    }
}
