<!DOCTYPE HTML>
<html lang="{lang}" id="{site_style}">
<head>
<title>{header_title}</title>
<meta charset="utf-8" />
<meta name="robots" content="index,follow" />
<meta name="viewport" content="initial-scale=1" />
<meta name="generator" content="Springheel" />
<link rel="stylesheet" type="text/css" href="assets/style.css" title="{stylesheet_name_s}" />
<link rel="icon" type="image/gif" href="assets/icon.gif" />
<link rel="home" href="index.html" title="{home_s}" />
{linkrels}
</head>
<body>
<p id="skippy"><a href="#main">{skip_s}</a></p>

<header>
<img id="banner" role="banner" src="{banner}" alt="{category}" />

<nav>
{top_site_nav}
</nav>
<h1 id="comictitle">{h1_title}</h1>
</header>

<main id="main" role="main" aria-labelledby="comictitle">
<div id="extras" class="main">
{extras}
</div>
</main>
<footer role="contentinfo">
{copyright_statement}
<p>{generator_s}</p>
<p class="sbuttons"><a href="feed.xml"><img src="socialbuttons/rss.png" alt="RSS Feed" width="24" height="24" /></a>  {icons}</p>
</footer>
</body>
</html>
