@import "shadow.scss";
@media screen {
/*Beach*/
    #beach {
    
    $bbg: #03475f;
    $mbg: #faefd9;
    
    $dt: #eee;
    $lt: #111;

    /* Default (small) screens */
        * {
            box-sizing: content-box;
        }
        body {
            background-color: $bbg;
            background: url("palm.png") no-repeat fixed 100% 100%, url("sea.jpg") repeat fixed;
            color: $lt;
            text-align: center;
            font-size: 1.5em;
            font-family: serif;
            margin: 0em;
        }

        main, figure {
            margin-left: 0em;
            padding-left: 0em;
        }

        main div, figure, .archive, footer, .cominavbox {
            background-color: $mbg;
            background-image: url("beach_sand.png");
            padding-left: 0.5em;
            padding-right: 0.5em;
        }
        
        main div, main section, figure#comic, .archive, h1, .cominavbox {
            @include shadow(0em, 0em, 0.5em, 0.5em, #94e8e8)
        }
        
        nav li, footer {
            @include shadow(0em, 0em, 0.2em, 0.2em, #94e8e8)
        }

        h1 {
            margin: 0em;
            margin-top: 1em;
            background-color: $mbg;
            background-image: url("beach_sand.png");
            padding: 1em;
        }
        figure {
            padding: 1em 0em;
            margin: 1em 0em;
            text-align: center;
        }
        .cominavbox, .cominavbox li {
            display: inline-block;
            padding: 0em;
            margin: 1em;
        }

        /*TODO: Fix the skip link hiding method*/
        #skippy {
            text-align: left;
            margin: 0em;
        }
        #skippy a, #skippy a:hover, #skippy a:visited {
            position:absolute;
            left:-10000px;
            top:auto;
            width:1px;
            height:1px;
            overflow:hidden;
        }

        #skippy a:active, #skippy a:focus {
          position: static;
          height: auto;
          width: auto;
          font-size: 1em;
          margin-top: 0em;
          color: #fff;
        }
        
        nav ul {
            padding-left: 0em;
        }

        nav li {
            display: inline-block;
            background-color: $mbg;
            background-image: url("beach_sand.png");
            padding: 0.5em;
            + li {
                margin-left: 0.5em;
            }
        }

        #commentary, #transcript {
            text-align: left;
        }

        .statline {
            font-weight: bold;
        }

        a:link {
            color: #1122aa;
            text-decoration: underline
        }

        a:visited {
            color: #661188;
        }

        a:hover {
            text-decoration: underline
        }

        a:hover, a:focus, a:active {
            color: #004466;
        }
        
        a:focus, a:active {
            outline: dashed medium #004466;
        }
        
        footer {
            margin-bottom: 0em;
            p {
                margin-left: 0em;
                text-align: left;
                &:last-of-type {
                    margin-bottom: 0em
                }
            }
        }

        .archive {
            display: inline-block;
            vertical-align: top;
            text-align: left;
        }

        img, embed, object, video {
            max-width: 100%;
        }

        .action {
            font-weight: bold;
        }
        
        .cominavbox {
            a:focus, a:active {
                outline: medium dashed #fda844;
            }
        }

        .cominavbox li img {
            display: inline;
        }
            
        .intro {
            border: none;
            background: none;
            margin: 0em;
            padding: 0em;
            width: 100%;
            -webkit-box-shadow: none;
            -moz-box-shadow: none;
            box-shadow: none;
        }
        
        .char {
            text-align: left;
            dt:after {
                content: ":"
            };
            dd:after {
                content: "\A"; white-space: pre;
            };
            dd {
                margin-left: 0em;
            };
            dt, dd {
                display: inline;
                white-space: pre;
            };
            .chartext {
            -webkit-box-shadow: none;
            -moz-box-shadow: none;
            box-shadow: none;
            }
        }

        * + * {
            margin-top: 1em
        }
        
        main {
            /*margin-top: 0em;*/
            div, section {
                padding: 1em 0.5em;
            }
            .main, .allchars, .char {
                margin-top: 2em;
            }
        }
        
        div + div, section + section {
            margin-top: 2em;
        }

    /*Medium screens*/

        @media screen and (min-width: 1024px) {
            body {
                margin: 0;
                padding-bottom: 0;
            }

            figure {
                padding: 1em;
                margin: 0em 1em;
                background-color: $mbg;
                background-image: url("beach_sand.png");
                & + .cominavbox {
                    margin-top: 1.5em;
                    margin-bottom: 0em;
                }
            }

            main {
                width: 80%;
                margin-left: 2em;
                margin-bottom: 2em;
            }

            main div, main section {
                margin-left: 1em;
                padding: 0em;
                padding: 0.1rem 1rem 0.2rem 1rem;
                width: 80%;
            }

            .cominavbox, .cominavbox li {
                margin: 1em;
            }

            h1 {
                font-size: 1.5em;
                max-width: 70%;
                margin: auto;
                margin-top: 2em;
                margin-bottom: 0em;
            }

            h2 {
                font-size: 1.2em;
            }
            
            h3 {
                font-size: 1em;
            }

            nav li {
                padding: 1em 1em 0.8em 1em;
                margin: 0em;
                & + li {
                    margin-left: 1em;
                }
            }

            .statline {
                font-size: 0.8em;
                text-align: right;
            }

            footer {
                margin: 1em 0em 0em 0em;
                padding: 0.2em;
                & p {
                    font-size: 0.7em;
                    text-align: left;
                    margin-left: 0.5em
                }
            }

            .archive {
                margin: 1em;
                padding-left: 1em;
                padding-right: 1em;
                width: 90%;
            }
            
            .main {
                padding: 0.5em;
                margin: auto;
                margin-top: 2em;
                width: 80%;
                text-align: left;
                & p {
                    margin-left: 0.5em;
                }
            }
            
            .intro {
                margin: 0em;
            }
            
            .intro + .intro {
                border-top: dashed thin $bbg;
            }
            
            .char {
                img {
                    margin: 0em 1em;
                }
            }

        }
    }
}
