@media screen {
  /*Beach*/
  #beach {
    /* Default (small) screens */
    /*TODO: Fix the skip link hiding method*/
    /*Medium screens*/ }
    #beach * {
      box-sizing: content-box; }
    #beach body {
      background-color: #03475f;
      background: url("palm.png") no-repeat fixed 100% 100%, url("sea.jpg") repeat fixed;
      color: #111;
      text-align: center;
      font-size: 1.5em;
      font-family: serif;
      margin: 0em; }
    #beach main, #beach figure {
      margin-left: 0em;
      padding-left: 0em; }
    #beach main div, #beach figure, #beach .archive, #beach footer, #beach .cominavbox {
      background-color: #faefd9;
      background-image: url("beach_sand.png");
      padding-left: 0.5em;
      padding-right: 0.5em; }
    #beach main div, #beach main section, #beach figure#comic, #beach .archive, #beach h1, #beach .cominavbox {
      -webkit-box-shadow: 0em 0em 0.5em 0.5em #94e8e8;
      -moz-box-shadow: 0em 0em 0.5em 0.5em #94e8e8;
      box-shadow: 0em 0em 0.5em 0.5em #94e8e8; }
    #beach nav li, #beach footer {
      -webkit-box-shadow: 0em 0em 0.2em 0.2em #94e8e8;
      -moz-box-shadow: 0em 0em 0.2em 0.2em #94e8e8;
      box-shadow: 0em 0em 0.2em 0.2em #94e8e8; }
    #beach h1 {
      margin: 0em;
      margin-top: 1em;
      background-color: #faefd9;
      background-image: url("beach_sand.png");
      padding: 1em; }
    #beach figure {
      padding: 1em 0em;
      margin: 1em 0em;
      text-align: center; }
    #beach .cominavbox, #beach .cominavbox li {
      display: inline-block;
      padding: 0em;
      margin: 1em; }
    #beach #skippy {
      text-align: left;
      margin: 0em; }
    #beach #skippy a, #beach #skippy a:hover, #beach #skippy a:visited {
      position: absolute;
      left: -10000px;
      top: auto;
      width: 1px;
      height: 1px;
      overflow: hidden; }
    #beach #skippy a:active, #beach #skippy a:focus {
      position: static;
      height: auto;
      width: auto;
      font-size: 1em;
      margin-top: 0em;
      color: #fff; }
    #beach nav ul {
      padding-left: 0em; }
    #beach nav li {
      display: inline-block;
      background-color: #faefd9;
      background-image: url("beach_sand.png");
      padding: 0.5em; }
      #beach nav li + li {
        margin-left: 0.5em; }
    #beach #commentary, #beach #transcript {
      text-align: left; }
    #beach .statline {
      font-weight: bold; }
    #beach a:link {
      color: #1122aa;
      text-decoration: underline; }
    #beach a:visited {
      color: #661188; }
    #beach a:hover {
      text-decoration: underline; }
    #beach a:hover, #beach a:focus, #beach a:active {
      color: #004466; }
    #beach a:focus, #beach a:active {
      outline: dashed medium #004466; }
    #beach footer {
      margin-bottom: 0em; }
      #beach footer p {
        margin-left: 0em;
        text-align: left; }
        #beach footer p:last-of-type {
          margin-bottom: 0em; }
    #beach .archive {
      display: inline-block;
      vertical-align: top;
      text-align: left; }
    #beach img, #beach embed, #beach object, #beach video {
      max-width: 100%; }
    #beach .action {
      font-weight: bold; }
    #beach .cominavbox a:focus, #beach .cominavbox a:active {
      outline: medium dashed #fda844; }
    #beach .cominavbox li img {
      display: inline; }
    #beach .intro {
      border: none;
      background: none;
      margin: 0em;
      padding: 0em;
      width: 100%;
      -webkit-box-shadow: none;
      -moz-box-shadow: none;
      box-shadow: none; }
    #beach .char {
      text-align: left; }
      #beach .char dt:after {
        content: ":"; }
      #beach .char dd:after {
        content: "\A";
        white-space: pre; }
      #beach .char dd {
        margin-left: 0em; }
      #beach .char dt, #beach .char dd {
        display: inline;
        white-space: pre; }
      #beach .char .chartext {
        -webkit-box-shadow: none;
        -moz-box-shadow: none;
        box-shadow: none; }
    #beach * + * {
      margin-top: 1em; }
    #beach main {
      /*margin-top: 0em;*/ }
      #beach main div, #beach main section {
        padding: 1em 0.5em; }
      #beach main .main, #beach main .allchars, #beach main .char {
        margin-top: 2em; }
    #beach div + div, #beach section + section {
      margin-top: 2em; } }
  @media screen and (min-width: 1024px) {
    #beach body {
      margin: 0;
      padding-bottom: 0; }
    #beach figure {
      padding: 1em;
      margin: 0em 1em;
      background-color: #faefd9;
      background-image: url("beach_sand.png"); }
      #beach figure + .cominavbox {
        margin-top: 1.5em;
        margin-bottom: 0em; }
    #beach main {
      width: 80%;
      margin-left: 2em;
      margin-bottom: 2em; }
    #beach main div, #beach main section {
      margin-left: 1em;
      padding: 0em;
      padding: 0.1rem 1rem 0.2rem 1rem;
      width: 80%; }
    #beach .cominavbox, #beach .cominavbox li {
      margin: 1em; }
    #beach h1 {
      font-size: 1.5em;
      max-width: 70%;
      margin: auto;
      margin-top: 2em;
      margin-bottom: 0em; }
    #beach h2 {
      font-size: 1.2em; }
    #beach h3 {
      font-size: 1em; }
    #beach nav li {
      padding: 1em 1em 0.8em 1em;
      margin: 0em; }
      #beach nav li + li {
        margin-left: 1em; }
    #beach .statline {
      font-size: 0.8em;
      text-align: right; }
    #beach footer {
      margin: 1em 0em 0em 0em;
      padding: 0.2em; }
      #beach footer p {
        font-size: 0.7em;
        text-align: left;
        margin-left: 0.5em; }
    #beach .archive {
      margin: 1em;
      padding-left: 1em;
      padding-right: 1em;
      width: 90%; }
    #beach .main {
      padding: 0.5em;
      margin: auto;
      margin-top: 2em;
      width: 80%;
      text-align: left; }
      #beach .main p {
        margin-left: 0.5em; }
    #beach .intro {
      margin: 0em; }
    #beach .intro + .intro {
      border-top: dashed thin #03475f; }
    #beach .char img {
      margin: 0em 1em; } }

/*# sourceMappingURL=style.css.map */
