@media screen {
  /*Two Thousand*/
  #twothousand {
    /*$accent-color: #800;*/
    /* Default (small) screens */
    /*TODO: Fix the skip link hiding method*/
    /*Medium screens*/
    /*Larger screens*/ }
    #twothousand * {
      box-sizing: content-box; }
    #twothousand body {
      background-color: #2b2b2b;
      color: #111;
      text-align: center;
      font-size: 1.5em;
      font-family: sans-serif;
      margin: 0; }
    #twothousand main, #twothousand figure {
      margin-left: 0em;
      padding-left: 0em; }
    #twothousand h1 {
      margin: 0em; }
    #twothousand figure {
      padding: 0em;
      margin-left: 0em;
      margin-right: 0em;
      text-align: center; }
      #twothousand figure img {
        margin: 0em; }
    #twothousand figcaption {
      margin-top: 0.5em;
      margin-bottom: 0.5em;
      padding: 0em; }
    #twothousand .cominavbox, #twothousand .cominavbox li {
      display: inline-block;
      padding: 0em; }
      #twothousand .cominavbox a, #twothousand .cominavbox li a {
        outline-width: medium;
        outline-color: #ffb300; }
    #twothousand p + p, #twothousand li + li {
      margin-top: 0.5em; }
    #twothousand #skippy {
      text-align: left;
      margin: 0em; }
    #twothousand #skippy a, #twothousand #skippy a:hover, #twothousand #skippy a:visited {
      position: absolute;
      left: -10000px;
      top: auto;
      width: 1px;
      height: 1px;
      overflow: hidden; }
    #twothousand #skippy a:active, #twothousand #skippy a:focus {
      position: static;
      height: auto;
      width: auto;
      font-size: 1em;
      margin-top: 0em;
      color: #bbf;
      margin: 1em;
      outline: dotted medium #bbf; }
    #twothousand nav, #twothousand h1, #twothousand h2, #twothousand h3 {
      background: #ffb326;
      /* Fallback for sad browsers */
      background-color: #ffb326;
      /* Mozilla Firefox */
      background-image: -moz-linear-gradient(#ffffcc, #ffb326);
      /* Opera */
      background-image: -o-linear-gradient(#ffffcc, #ffb326);
      /* WebKit (Chrome 11+) */
      background-image: -webkit-gradient(linear, left top, left bottom, color-stop(0, #ffffcc), color-stop(1, #ffb326));
      /* WebKit (Safari 5.1+, Chrome 10+) */
      background-image: -webkit-linear-gradient(#ffffcc, #ffb326);
      /* IE10 */
      background-image: -ms-linear-gradient(#ffffcc, #ffb326);
      /* W3C */
      background-image: linear-gradient(#ffffcc, #ffb326);
      border: solid thin #7f7f7f;
      border-left: none;
      border-right: none;
      color: #222; }
    #twothousand nav {
      margin-bottom: 0em;
      text-align: center; }
      #twothousand nav ul {
        margin-bottom: 0em;
        margin-top: 0em; }
      #twothousand nav li {
        display: inline-block; }
      #twothousand nav li + li {
        margin-left: 1em; }
      #twothousand nav a:link {
        text-decoration: none; }
      #twothousand nav a:hover {
        text-decoration: underline; }
    #twothousand header {
      margin-top: 0em;
      padding-top: 0em;
      width: 100%; }
      #twothousand header img {
        margin: 0em;
        padding: 0em; }
    #twothousand main {
      /*background: #ddd;*/
      background: #222262;
      color: #eee;
      border: solid thin #7f7f7f;
      border-left: none;
      border-right: none; }
      #twothousand main div {
        text-align: left; }
    #twothousand .statline {
      font-weight: bold; }
    #twothousand a:link {
      color: #0000c1;
      text-decoration: underline; }
    #twothousand a:visited {
      color: #46284c; }
    #twothousand a:hover, #twothousand a:focus, #twothousand a:active {
      color: #700404; }
    #twothousand main a:link {
      color: #abbdee; }
    #twothousand main a:visited {
      color: #daadf0; }
    #twothousand main a:hover, #twothousand main afocus, #twothousand main a:active {
      color: #eeaeb6; }
    #twothousand footer {
      color: #ffd; }
      #twothousand footer a:link {
        color: #bbf;
        text-decoration: underline; }
      #twothousand footer a:visited {
        color: #daf; }
      #twothousand footer a:hover, #twothousand footer a:focus, #twothousand footer a:active {
        color: #ffaaaa; }
      #twothousand footer p {
        margin-left: 0em;
        text-align: left; }
    #twothousand .archive {
      vertical-align: top;
      text-align: left; }
      #twothousand .archive h2 {
        border: none;
        background: none;
        margin-top: 0.5em;
        color: inherit; }
      #twothousand .archive h3 {
        border: none;
        background: none;
        margin-left: 1em;
        margin-top: 0em;
        color: inherit; }
      #twothousand .archive ol {
        margin-top: 0em;
        margin-left: 1em; }
    #twothousand img, #twothousand embed, #twothousand object, #twothousand video {
      max-width: 100%; }
    #twothousand .action {
      font-weight: bold; }
    #twothousand .char {
      text-align: left; }
      #twothousand .char dt:after {
        content: ":"; }
      #twothousand .char dd:after {
        content: "\A";
        white-space: pre; }
      #twothousand .char dd {
        margin-left: 0em; }
      #twothousand .char dt, #twothousand .char dd {
        display: inline;
        white-space: pre; }
    #twothousand .status {
      text-indent: 2em;
      font-size: .9em;
      font-weight: bold;
      margin-top: 0em; }
    #twothousand .char:first-of-type h2 {
      border-top: none;
      margin-top: 0em; } }
  @media screen and (min-width: 640px) {
    #twothousand body {
      font-size: 1.5em; }
    #twothousand figure {
      padding: 1em 1em 0em 1em;
      margin-left: 1em;
      margin-top: 0em;
      margin-bottom: 0em; }
      #twothousand figure + .cominavbox {
        margin-top: 0em; }
    #twothousand nav, #twothousand h1, #twothousand h2, #twothousand h3, #twothousand main {
      border: solid thin #7f7f7f; }
    #twothousand main div {
      padding-left: 0em;
      padding-right: 0em;
      margin: 1em 0em 1em 0em; }
      #twothousand main div p {
        margin-left: 1em; }
    #twothousand div + div {
      margin-bottom: 0em;
      margin-top: 0em; }
    #twothousand .cominavbox, #twothousand .cominavbox li {
      margin: 0.5em 1em 0em 1em; }
    #twothousand h1 {
      font-size: 1.5em;
      border-bottom: none;
      border-top: none;
      padding-top: 0.5em;
      padding-bottom: 0.5em;
      text-align: center; }
    #twothousand h2 {
      font-size: 1.2em;
      margin: 0em;
      padding: 0.5em 0em 0.5em 0.5em;
      border-left: none;
      border-right: none; }
    #twothousand h3 {
      font-size: 1em; }
    #twothousand header {
      margin-left: 1em; }
    #twothousand nav {
      text-align: right;
      font-size: 1rem; }
    #twothousand nav li {
      padding: 1em 1em 0.8em 1em;
      margin: 0em; }
      #twothousand nav li + li {
        border-left: solid thin #7f7f7f;
        margin-left: 0em; }
    #twothousand .statline {
      font-size: 0.8em;
      text-align: right;
      margin-right: 1em; }
    #twothousand footer p {
      font-size: 0.7em;
      margin-left: 1em; }
    #twothousand h1, #twothousand main, #twothousand nav {
      width: auto;
      margin-right: 1em;
      max-width: 80%; }
    #twothousand header {
      text-align: left;
      max-width: 100%;
      margin-left: 0em; }
    #twothousand header img {
      max-width: 90%;
      margin: 0em; }
    #twothousand nav, #twothousand h1 {
      margin-left: 0em; }
    #twothousand nav ul {
      padding-inline-start: 0em; }
    #twothousand .main {
      padding: 0em;
      margin: 0em;
      width: 100%; }
      #twothousand .main p {
        margin-left: 0em; }
    #twothousand .intro {
      padding: 0em;
      margin: 0em;
      width: 100%; }
      #twothousand .intro .author {
        font-weight: bold; }
      #twothousand .intro .desc {
        font-size: .8em;
        text-indent: 1em; }
      #twothousand .intro h2 {
        border-top: none;
        text-align: center; }
      #twothousand .intro p {
        padding: 0em 1em 1em 1em; }
    #twothousand .char {
      padding: 0em; }
      #twothousand .char img {
        margin: 0em 1em 1em 0em; }
      #twothousand .char .chartext {
        margin: 0em;
        text-align: left; }
      #twothousand .char .chartext, #twothousand .char img {
        display: inline-block;
        vertical-align: top;
        max-width: 70%; }
      #twothousand .char:first-of-type {
        margin-top: 0em; }
        #twothousand .char:first-of-type h2 {
          border-top: none;
          margin-top: 0em; } }
  @media screen and (min-width: 1280px) {
    #twothousand nav {
      font-size: 1em; }
    #twothousand h1, #twothousand main, #twothousand nav {
      width: auto;
      margin-right: 1em;
      max-width: 70%; } }

/*# sourceMappingURL=style.css.map */
