@import "shadow.scss";
@import "gradient.scss";
@media screen {
/*Magic Circle*/
    #magiccircle {

    $bg-color: #002;
    $half-bg: rgba(0, 0, 34, 0.75);
    $borders: #f48bff;
    $out-text: #f9c2ff;
    $in-text: #f9c2ff;
    /* Default (small) screens */
        * {
            box-sizing: content-box;
        }
        body {
            background: $bg-color;
            color: $out-text;
            text-align: center;
            font-size: 1.5em;
            font-family: serif;
            margin: 0;
        }
        
        main div, main section, nav li {
            background: $half-bg;
            border: solid thin $borders;
            color: $in-text;
        }

        main, figure {
            margin-left: 0em;
            padding-left: 0em;
        }

        h1 {
            margin: 0em;
            text-shadow: 0em 0em 0.2em $bg-color,
                         0em 0em 0.2em $bg-color,
                         0em 0em 0.2em $bg-color,
                         0em 0em 0.2em $bg-color,
                         0em 0em 0.2em $bg-color,
                         0em 0em 0.5em $bg-color,
                         0em 0em 0.5em $bg-color;
        }

        figure#comic {
            padding: 1em 0em 0em 0em;
            margin-left: 0em;
            margin-right: 0em;
            text-align: center;
            border: none;
            border-bottom: solid thin $borders;
            & img {
                margin: 0em;
            }
        }

        figcaption {
            margin-bottom: 0.5em;
            padding: 0em;
        }
        .cominavbox, .cominavbox li {
            display: inline-block;
            padding: 0em;
        }

        p + p, li + li, div + div, section + section, figcaption {
            margin-top: 0.5em
        }

        #skippy {
            text-align: left;
            margin: 0em
        }
        #skippy a, #skippy a:hover, #skippy a:visited {
            position:absolute;
            left:-10000px;
            top:auto;
            width:1px;
            height:1px;
            overflow:hidden;
        }

        #skippy a:active, #skippy a:focus {
          position: static;
          height: auto;
          width: auto;
          font-size: 1em;
          margin-top: 0em;
          color: #bbf;
          margin: 1em;
          outline: dotted medium #bbf
        }

        nav {
            margin-bottom: 0em;
            & ul {
                margin: 0em;
                padding-left: 0em;
            };
            & li {
                display: inline-block;
                padding: 0.5em;
            };
            & li + li {
                margin-left: 1em;
                border: solid thin $borders
            };
            & a:link {
                text-decoration: none
            };
            & a:hover {
                text-decoration: underline
            }
        }

        header {
            margin-top: 0em;
            padding-top: 0em;
            & img {
                margin-top: 0em;
                padding-top: 0em;
                display: inline
            }
        }

        main {
            & div {
                text-align: left;
                padding: 0.5em 0em 0.5em 0.2em;
            }
        }

        .statline {
            font-weight: bold;
        }

        a:link {
            color: #bad3ff;
            text-decoration: underline
        }

        a:visited {
            color: #d1adff;
        }

        a:hover, a:focus, a:active {
            color: #ffabab;
        }

        footer {
            & a:link {
                color: #bbf;
                text-decoration: underline
            };
            & a:visited {
                color: #daf;
            };
            & a:hover, & a:focus, & a:active {
                color: #ffaaaa;
            };
            & p {
                margin-left: 0em;
                text-align: left;
            }
        }

        .archive {
            vertical-align: top;
            text-align: left;
            h2 {
                margin-top: 0.5em;
            };
            ol {
                margin-top: 0em;
            }
        }

        img, embed, object, video {
            max-width: 100%;
        }

        .action {
            font-weight: bold;
        }

        .charname {
            font-weight: bold
        }
        
        .chartext {
            border: none;
        }
            
        .cominavbox {
            background: $half-bg;
            margin-bottom: 0em;
            border: thin solid $borders;
            li {
                padding: 0.5em;
            }
        }
        figure#comic {
            margin-top: 0em;
            padding-top: 0em;
            margin-bottom: 0em;
            border: thin solid $borders;
        }
            
        figcaption {
            margin-bottom: 0em;
            padding-top: 0.5em;
        }
        figure + .cominavbox {
            margin-top: 0em;
            li {
                margin-top: 0em;
                padding: 0.5em;
            }
            margin-bottom: 1em
        }
            
        .intro {
            border: none;
            background: none;
            margin: 0em;
            padding: 0em;
            & + .intro {
                border-top: solid thin $borders;
            }
            h2 {
                margin-top: 0em;
                padding-top: 0em;
            }
        }
        
        .char {
            text-align: left;
            h2 {
                margin-left: 1em;
                padding-top: 1em;
            };
            dt:after {
                content: ":"
            };
            dd:after {
                content: "\A"; white-space: pre;
            };
            dd {
                margin-left: 0em;
            };
            dt, dd {
                display: inline;
                white-space: pre;
            };
            dl {
                font-size: 0.9em;
                margin-left: 1em;
            };
            img {
                border: solid thin $borders;
            };
        }

    /*Medium screens*/

        @media screen and (min-width: 1024px) {
            body {
                background: $bg-color url("glowy-magic-circle.jpg") fixed no-repeat 100% 0%;
                background-size: 50%;
            }

            figure#comic {
                padding: 0em;
                @include shadow(0em,0em,0.5em,0.5em,$borders);
                margin-left: 1em;
                margin-top: 0em;
                margin-bottom: 0em;
                background: $half-bg;
                img {
                    display: inline;
                    border-bottom: solid thin $borders;
                }
            }
            
            figcaption {
                font-size: 1.2em;
                padding: 0.5em 1em 1em 0.5em;
                margin: 0em;
            }

            main {
                margin-left: 10%;
                width: 70%;
                div, section {
                    padding: 0em 0em 0.5em 0em;
                    margin: 1em 2em 1em 0em;
                    & p {
                        margin-left: 1em
                    }
                }
            }
            
            .cominavbox {
                background: $half-bg;
                li {
                    margin-bottom: 1em;
                    padding-bottom: 1em;
                }
            }
            figure + .cominavbox {
                margin-top: 0em;
                li {
                    margin-top: 0em;
                    padding-top: 0.5em;
                }
            }

            .cominavbox, .cominavbox li {
                margin: 0.5em 1em 0em 1em;
            }

            h1 {
                font-size: 1.5em;
                border-bottom: none;
                border-top: none;
                padding-top: 0.5em;
                padding-bottom: 0.5em;
                width: 70%;
                margin-left: 10%;
            }

            h2 {
                font-size: 1.2em;
                margin: 0em;
                padding: 0.5em 0em 0.5em 0.5em;
            }
            
            h3 {
                font-size: 1em;
                padding-left: 1em;
            }

            nav {
                text-align: center;
                background: none;
            }

            nav li {
                padding: 1em 1em 0.8em 1em;
                margin: 0em;
                border: solid thin $borders;
                & + li {
                    margin-left: 0em;
                }
            }

            .statline {
                font-size: 0.8em;
                text-align: right;
                margin-right: 1em
            }

            footer p {
                font-size: 0.7em;
                margin-left: 1em
            }

            .action {
                text-indent: 1em;
            }
            
            .archive {
                padding: 0em 0em 0.5em 0em;
                width: 80%;
                ol {
                    margin-top: 1em;
                    margin-left: 1em;
                    margin-right: 2em;
                    border-right: solid thin $borders;
                };
                h2 {
                    padding: 0em;
                    margin: 0em;
                    margin-left: 1em;
                    margin-top: 0.7em;
                }
            }
            
            .main {
                padding: 0.5em;
                & p {
                    margin-left: 0em;
                };
                .intro h2 {
                    margin-top: 0.5em
                }
            }
            
            .char {
                img {
                    margin: 0em 2em 1em 1em; 
                }
                .chartext {
                    margin: 0em;
                    text-align: left;
                    background: none;
                    p {
                        margin: 0em;
                        padding: 0em
                    }
                }
                .chartext, img {
                    display: inline-block;
                    vertical-align: top;
                    max-width: 50%;
                }
            }

        }
    }
}
