@media screen {
  /*Gothic*/
  #gothic {
    /* Default (small) screens */
    /*TODO: Fix the skip link hiding method*/
    /*Medium screens*/ }
    #gothic * {
      box-sizing: content-box; }
    #gothic body {
      background-color: #100;
      color: #b7f;
      text-align: center;
      font-size: 1.5em;
      font-family: serif;
      margin: 0em; }
    #gothic img, #gothic embed, #gothic object, #gothic video {
      max-width: 100%; }
    #gothic main, #gothic figure {
      margin-left: 0em;
      padding-left: 0em; }
    #gothic figure {
      padding: 0em;
      text-align: center;
      border: none; }
    #gothic #skippy {
      text-align: left;
      margin: 0em; }
    #gothic #skippy a, #gothic #skippy a:hover, #gothic #skippy a:visited {
      position: absolute;
      left: -10000px;
      top: auto;
      width: 1px;
      height: 1px;
      overflow: hidden; }
    #gothic #skippy a:active, #gothic #skippy a:focus {
      position: static;
      height: auto;
      width: auto;
      font-size: 1em;
      margin-top: 0em;
      color: #0000ff; }
    #gothic nav ul {
      padding-left: 0em; }
    #gothic nav li {
      display: inline-block; }
      #gothic nav li + li {
        border-left: solid thin #e00;
        padding-left: 0.5em; }
    #gothic #commentary, #gothic #transcript {
      text-align: left; }
    #gothic .statline {
      font-weight: bold; }
    #gothic a:link {
      color: #3e9fff;
      text-decoration: underline; }
    #gothic a:visited {
      color: #a78ae2; }
    #gothic a:hover {
      text-decoration: underline; }
    #gothic a:hover, #gothic a:focus, #gothic a:active {
      color: #f77; }
    #gothic footer p {
      margin-left: 0em;
      text-align: left; }
    #gothic .archive {
      vertical-align: top;
      text-align: left; }
    #gothic .cominavbox {
      margin: 0em;
      padding: 0em; }
      #gothic .cominavbox li {
        display: inline-block;
        padding: 0.5em;
        margin: 0em; }
    #gothic .action {
      font-weight: bold; }
    #gothic p + p, #gothic li + li, #gothic div + div {
      margin-top: 0.5em; }
    #gothic main div, #gothic .archive {
      border: double medium #e00;
      border-left: none;
      border-right: none; }
    #gothic h1 {
      margin: 0em;
      margin-bottom: 1em; }
    #gothic .char {
      text-align: left; }
      #gothic .char dt:after {
        content: ":"; }
      #gothic .char dd:after {
        content: "\A";
        white-space: pre; }
      #gothic .char dd {
        margin-left: 0em; }
      #gothic .char dt, #gothic .char dd {
        display: inline;
        white-space: pre; }
      #gothic .char dt {
        font-weight: bold; }
      #gothic .char dl {
        font-size: 0.9em; }
      #gothic .char img {
        margin: 1em;
        border: double medium #e00; }
      #gothic .char p {
        text-indent: 1em; } }
  @media screen and (min-width: 1024px) {
    #gothic body {
      font-size: 1.5em;
      margin-left: 1em;
      background: url("drips.gif") fixed repeat-x 0% 0%, #100 url("rose-tall.gif") fixed no-repeat 100% 100%;
      margin: 0em; }
    #gothic figure {
      margin-left: 1em;
      margin-top: 0em;
      margin-bottom: 0em; }
    #gothic main div, #gothic main section {
      padding-left: 1em;
      padding-right: 1em;
      width: 80%;
      margin-top: 1em; }
    #gothic .cominavbox {
      margin: 0em;
      padding: 1em; }
    #gothic .cominavbox li {
      margin: 0.5em 1em 0em 1em; }
    #gothic figure + .cominavbox {
      margin-top: 0em; }
    #gothic figure {
      margin-left: 1em; }
    #gothic h1 {
      font-size: 1.5em; }
    #gothic h2 {
      font-size: 1.2em; }
    #gothic h3 {
      font-size: 1em; }
    #gothic .statline {
      font-size: 0.8em;
      text-align: right; }
    #gothic footer p {
      font-size: 0.7em; }
    #gothic .archive {
      margin-left: 1em;
      margin-right: 1em;
      padding-left: 1em;
      padding-right: 1em; }
    #gothic figure, #gothic main div, #gothic .archive, #gothic nav li {
      border: double medium #e00;
      background: #100; }
    #gothic nav li, #gothic nav li + li {
      border: none;
      border: double medium #e00;
      padding: 0em;
      padding: 0.5em; }
    #gothic h2 {
      border-bottom: solid thin #e00; }
    #gothic h1 {
      margin-bottom: 1em; }
    #gothic .action {
      text-indent: 1em; }
    #gothic .main {
      padding: 0.5em;
      margin: auto;
      margin-top: 1em;
      width: 50%;
      text-align: center; }
      #gothic .main p {
        margin-left: 0em; }
    #gothic .intro {
      border: none;
      margin: 0em;
      padding: 0em;
      text-align: left; }
      #gothic .intro h2 {
        margin-bottom: 0.5em; }
      #gothic .intro img {
        display: inline; }
      #gothic .intro .author {
        font-size: 0.8em; }
      #gothic .intro .desc {
        font-weight: bold; }
    #gothic .char img {
      margin: 0em 1em 1em 0em; }
    #gothic .char .chartext {
      margin: 0em; }
    #gothic .char .chartext, #gothic .char img {
      display: inline-block;
      vertical-align: top;
      max-width: 50%; } }

/*# sourceMappingURL=style.css.map */
